package com.sun.jmx.snmp.IPAcl;

import java.security.acl.Permission;
import java.util.Enumeration;
import java.security.acl.NotOwnerException;
import java.security.Principal;
import java.security.acl.AclEntry;
import java.util.Vector;
import java.io.Serializable;
import java.security.acl.Acl;

class AclImpl extends OwnerImpl implements Acl, Serializable
{
    private static final long serialVersionUID = -2250957591085270029L;
    private Vector<AclEntry> entryList;
    private String aclName;
    
    public AclImpl(PrincipalImpl principalImpl, String aclName) {
        super(principalImpl);
        this.entryList = null;
        this.aclName = null;
        this.entryList = new Vector();
        this.aclName = aclName;
    }
    
    public void setName(Principal principal, String aclName) throws NotOwnerException {
        if (!this.isOwner(principal)) {
            throw new NotOwnerException();
        }
        this.aclName = aclName;
        return;
    }
    
    public String getName() {
        return this.aclName;
    }
    
    public boolean addEntry(Principal principal, AclEntry aclEntry) throws NotOwnerException {
        if (!this.isOwner(principal)) {
            throw new NotOwnerException();
        }
        if (this.entryList.contains(aclEntry)) {
            return false;
        }
        this.entryList.addElement(aclEntry);
        return true;
    }
    
    public boolean removeEntry(Principal principal, AclEntry obj) throws NotOwnerException {
        if (!this.isOwner(principal)) {
            throw new NotOwnerException();
        }
        return this.entryList.removeElement(obj);
    }
    
    public void removeAll(Principal principal) throws NotOwnerException {
        if (!this.isOwner(principal)) {
            throw new NotOwnerException();
        }
        this.entryList.removeAllElements();
        return;
    }
    
    public Enumeration<Permission> getPermissions(Principal principal) {
        Vector<Object> vector = new Vector();
        Enumeration<AclEntry> elements = this.entryList.elements();
        while (elements.hasMoreElements()) {
            AclEntry aclEntry = (AclEntry)elements.nextElement();
            if (aclEntry.getPrincipal().equals(principal)) {
                return aclEntry.permissions();
            }
            continue;
        }
        return vector.elements();
    }
    
    public Enumeration<AclEntry> entries() {
        return this.entryList.elements();
    }
    
    public boolean checkPermission(Principal principal, Permission permission) {
        Enumeration<AclEntry> elements = this.entryList.elements();
        while (elements.hasMoreElements()) {
            AclEntry aclEntry = (AclEntry)elements.nextElement();
            if (aclEntry.getPrincipal().equals(principal) && aclEntry.checkPermission(permission)) {
                return true;
            }
            continue;
        }
        return false;
    }
    
    public boolean checkPermission(Principal principal, String s, Permission permission) {
        Enumeration<AclEntry> elements = this.entryList.elements();
        while (elements.hasMoreElements()) {
            AclEntryImpl aclEntryImpl = (AclEntryImpl)elements.nextElement();
            if (aclEntryImpl.getPrincipal().equals(principal) && aclEntryImpl.checkPermission(permission) && aclEntryImpl.checkCommunity(s)) {
                return true;
            }
            continue;
        }
        return false;
    }
    
    public boolean checkCommunity(String s) {
        Enumeration<AclEntry> elements = this.entryList.elements();
        while (elements.hasMoreElements()) {
            if (((AclEntryImpl)elements.nextElement()).checkCommunity(s)) {
                return true;
            }
            continue;
        }
        return false;
    }
    
    public String toString() {
        return "AclImpl: " + this.getName();
    }
}
